Class: Pageflow::LegalInfo

Inherits:
Object
  • Object
show all
Defined in:
app/models/pageflow/legal_info.rb

Overview

Legal info of a site, resolved for a single locale. Each attribute falls back to the value stored in the site's column when there is no translation for the locale.

Since:

  • 17.2

Defined Under Namespace

Classes: Link

Instance Method Summary collapse

Constructor Details

#initialize(site, locale) ⇒ LegalInfo

Returns a new instance of LegalInfo.

Since:

  • 17.2



10
11
12
13
# File 'app/models/pageflow/legal_info.rb', line 10

def initialize(site, locale)
  @site = site
  @locale = locale
end

Instance Method Details

Since:

  • 17.2



19
20
21
# File 'app/models/pageflow/legal_info.rb', line 19

def copyright
  @copyright ||= link('copyright')
end

#imprintObject

Since:

  • 17.2



15
16
17
# File 'app/models/pageflow/legal_info.rb', line 15

def imprint
  @imprint ||= link('imprint')
end

#privacy_urlObject

Since:

  • 17.2



23
24
25
# File 'app/models/pageflow/legal_info.rb', line 23

def privacy_url
  translated(:privacy_link_url)
end