Class: Pageflow::LegalInfo
- Inherits:
-
Object
- Object
- Pageflow::LegalInfo
- Defined in:
- app/models/pageflow/legal_info.rb
Overview
Legal info of a site, resolved for a single locale. Each attribute falls back to the value stored in the site's column when there is no translation for the locale.
Defined Under Namespace
Classes: Link
Instance Method Summary collapse
- #copyright ⇒ Object
- #imprint ⇒ Object
-
#initialize(site, locale) ⇒ LegalInfo
constructor
A new instance of LegalInfo.
- #privacy_url ⇒ Object
Constructor Details
#initialize(site, locale) ⇒ LegalInfo
Returns a new instance of LegalInfo.
10 11 12 13 |
# File 'app/models/pageflow/legal_info.rb', line 10 def initialize(site, locale) @site = site @locale = locale end |
Instance Method Details
#copyright ⇒ Object
19 20 21 |
# File 'app/models/pageflow/legal_info.rb', line 19 def copyright @copyright ||= link('copyright') end |
#imprint ⇒ Object
15 16 17 |
# File 'app/models/pageflow/legal_info.rb', line 15 def imprint @imprint ||= link('imprint') end |
#privacy_url ⇒ Object
23 24 25 |
# File 'app/models/pageflow/legal_info.rb', line 23 def privacy_url translated(:privacy_link_url) end |